﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;

/*
 * File Renaming Wizard copyright (c) 2014 Matthew Schlachter
 * See LICENSE.txt for distribution and modification restrictions
 * 
 * http://www.webmann.info/
 */
namespace FileRenamingWizard
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public List<String> files = new List<String>();

        public MainWindow()
        {
            InitializeComponent();

            //==[ Set up the drop handlers to drop files into the main window
            this.AllowDrop = true;
            this.DragEnter += new DragEventHandler(MainWindow_DragEnter);
            this.Drop += new DragEventHandler(MainWindow_DragDrop);
        }

        void MainWindow_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop)) e.Effects = DragDropEffects.Copy;
        }

        void MainWindow_DragDrop(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
            {
                //==[ Fetch the dropped file name(s) into an array
                string[] filesStr = e.Data.GetData(DataFormats.FileDrop) as string[];
                foreach (string file in filesStr)
                {
                    if (Directory.Exists(file))
                    {
                        //==[ If directory add files from the directory
                        GetFilesFromDirectory(file);
                    }
                    else
                    {
                        //==[ If not directory add file to list
                        if (!file.Contains("Thumbs.db"))
                            files.Add(file);
                    }
                }
                //==[ Begin renaming files...
                if (files.Count > 0)
                {
                    new ProcessingWindow(new FileRenamingManager(files.ToArray())).Show();
                    this.Close();
                }
            }
        }

        /// <summary>
        /// Add files to the list from a directory and any sub directories
        /// (recursive)
        /// </summary>
        /// <param name="directory"></param>
        private void GetFilesFromDirectory(string directory)
        {
            try
            {
                foreach (string file in Directory.GetFiles(directory))
                {
                    //==[ Exclude files named 'Thumbs.db'
                    if (!file.Contains("Thumbs.db"))
                        files.Add(file);
                }
                foreach (string d in Directory.GetDirectories(directory))
                {
                    //==[ If directory fetch the files from the directory
                    GetFilesFromDirectory(d);
                }
            }
            catch (Exception e)
            {
                System.Diagnostics.Debug.WriteLine(e.Message);
            }
        }
    }
}
